ModelBuildError

Enum ModelBuildError 

pub enum ModelBuildError {
Show 13 variants DuplicateParameterNames { function_parameters: Vec<String>, }, EmptyParameters, FunctionParameterNotInModel { function_parameter: String, }, InvalidDerivative { parameter: String, function_parameters: Vec<String>, }, DuplicateDerivative { parameter: String, }, MissingDerivative { missing_parameter: String, function_parameters: Vec<String>, }, EmptyModel, UnusedParameter { parameter: String, }, IncorrectParameterCount { actual: usize, expected: usize, }, CommaInParameterNameNotAllowed { param_name: String, }, MissingX, MissingInitialParameters, IllegalCallToPartialDeriv,
}
An error structure that contains error variants that occur when building a model.

Variants



DuplicateParameterNames

Model or function parameters contain duplicates

Fields

function_parameters: Vec<String>

the given parameter list containing duplicates



EmptyParameters

Model or function parameter list is empty. To add functions that are independent of model parameters, use the interface for adding invariant functions.



FunctionParameterNotInModel

A function was added to the model which depends on parameters which are not in the model

Fields

function_parameter: String

the name of the parameter not in the set



InvalidDerivative

Tried to provide a partial derivative with respect to a parameter that a function does not depend on

Fields

parameter: String

paramter where a derivative was provided

function_parameters: Vec<String>

the actual parameters this function depends on



DuplicateDerivative

Tried to provide the same partial derivative twice.

Fields

parameter: String

the name of the derivative specified twice



MissingDerivative

Not all partial derivatives for a function where given. Each function must be given a partial derivative with respect to each parameter it depends on.

Fields

missing_parameter: String

this parameter misses a derivative

function_parameters: Vec<String>

the parameters that this function depends on



EmptyModel

Tried to construct a model without base functions



UnusedParameter

The model depends on a certain parameter that none of the base functions depend on.

Fields

parameter: String

the unused parameter name



IncorrectParameterCount

This error indicates that the more or fewer string parameters where provided as function parameters than the actual variadic function takes. This might accidentally happen when giving a derivative that does not depend on a certain parameter, whereas the base function does. However, the library requires that the derivatives take all the parameters its base function takes in the same order.

Fields

actual: usize

the actual number of arguments

expected: usize

the number of



CommaInParameterNameNotAllowed

Parameter names may not contain a comma separator, because this is most likely caused by a typo, i.e. ["tau,phi"], instead of actually ["tau","phi"]. So this is forbidden in order to help spotting these hard to find errors.

Fields

param_name: String

the parameter name



MissingX

x-vector (independent variable) was not supplied to the model builder



MissingInitialParameters

missing initial guesses for parameters



IllegalCallToPartialDeriv

an illegal call to the partial_deriv function