SvdLinearSolver

Struct SvdLinearSolver 

pub struct SvdLinearSolver<ScalarType>
where ScalarType: Scalar + ComplexField,
{ /* private fields */ }
A solver for the linear subproblem in variable projection that uses singular value decomposition to calculate the linear solution. It is well equipped to deal with numerically difficult problems that might become rank deficient during the optimization. The high numerical stability means that it will suffer in performance compared to other solvers in this crate, but it is a good default choice and varpro with SVD will outperform pure nonlinear optimizers any day of the week.

Details

The solver uses the singular value decomposition with a Kaufmann approximation for the derivatives as described here.